await_send_within

Function await_send_within 

pub(crate) async fn await_send_within(
    client: &Client,
    operation_id: OperationId,
    watch: Duration,
) -> Result<Option<FinalSendOperationState>>
Waits up to watch for a send to reach its final state, returning None if it is still unresolved by then.