join_client

Function join_client 

pub(crate) async fn join_client(name: &str, invite_code: &str) -> Result<Client>
Creates a fresh client and joins it to the federation identified by invite_code, unlike Federation::new_joined_client which always joins whichever federation last wrote the shared invite-code file.